@@ -26,7 +26,7 @@ class SignalArithmetique(SignalBase):
             test = self.base_de_temps == other.base_de_temps
             if not test:
                 print("Opération arithmétique: Les deux signaux doivent avoir la même base de temps")
-                exit()
+                sys.exit()
             sortie.vecteur_signal = self.vecteur_signal + other.vecteur_signal
             sortie.nom = "({0}  + {1})".format(self.nom, other.nom)
         assert test == True, "Opération arithmétique impossible entre {0} et {1}".format(type(self), type(other))
@@ -43,7 +43,7 @@ class SignalArithmetique(SignalBase):
             test = self.base_de_temps == other.base_de_temps
             if not test:
                 print("Opération arithmétique: Les deux signaux doivent avoir la même base de temps")
-                exit()
+                sys.exit()
             sortie.vecteur_signal = other.vecteur_signal + self.vecteur_signal
             sortie.nom = "({0}  + {1})".format(other.nom, self.nom)
         assert test == True, "Opération arithmétique impossible entre {0} et {1}".format(type(self), type(other))
@@ -60,7 +60,7 @@ class SignalArithmetique(SignalBase):
             test = self.base_de_temps == other.base_de_temps
             if not test:
                 print("Opération arithmétique: Les deux signaux doivent avoir la même base de temps")
-                exit()
+                sys.exit()
             sortie.vecteur_signal = self.vecteur_signal - other.vecteur_signal
             sortie.nom = "({0} - {1})".format(self.nom, other.nom)
         assert test == True, "Opération arithmétique impossible entre {0} et {1}".format(type(self), type(other))
@@ -77,7 +77,7 @@ class SignalArithmetique(SignalBase):
             test = self.base_de_temps == other.base_de_temps
             if not test:
                 print("Opération arithmétique: Les deux signaux doivent avoir la même base de temps")
-                exit()
+                sys.exit()
             sortie.vecteur_signal = other.vecteur_signal - self.vecteur_signal
             sortie.nom = "({0}  - {1})".format(other.nom, self.nom)
         assert test == True, "Opération arithmétique impossible entre {0} et {1}".format(type(self), type(other))
@@ -94,7 +94,7 @@ class SignalArithmetique(SignalBase):
             test = self.base_de_temps == other.base_de_temps
             if not test:
                 print("Opération arithmétique: Les deux signaux doivent avoir la même base de temps")
-                exit()
+                sys.exit()
             sortie.vecteur_signal = self.vecteur_signal * other.vecteur_signal
             sortie.nom = "({0} $\\times$ {1})".format(self.nom, other.nom)
         assert test == True, "Opération arithmétique impossible entre {0} et {1}".format(type(self), type(other))
@@ -111,7 +111,7 @@ class SignalArithmetique(SignalBase):
             test = self.base_de_temps == other.base_de_temps
             if not test:
                 print("Opération arithmétique: Les deux signaux doivent avoir la même base de temps")
-                exit()
+                sys.exit()
             sortie.vecteur_signal = other.vecteur_signal * self.vecteur_signal
             sortie.nom = "({0} $\\times$ {1})".format(other.nom, self.nom)
         assert test == True, "Opération arithmétique impossible entre {0} et {1}".format(type(self), type(other))
